@@ -1,4 +1,5 @@
 using System.Linq;
+using System.Runtime.InteropServices;
 using My.Company;
 using Xunit;
 
@@ -24,6 +25,25 @@ namespace interop_test
                 return x0[0];
             });
         }
+        
+        [Fact]
+        public void pattern_ffi_slice_3()
+        {
+            var data = new byte[100_000];
+            var handle = GCHandle.Alloc(data, GCHandleType.Pinned);
+            var slice = new FFISliceMutu8(handle, 100_000);
+            
+            Interop.pattern_ffi_slice_3(slice, x0 =>
+            {
+                x0[1] = 100;
+            });
+            
+            handle.Free();
+            
+            Assert.Equal(data[0], 1);
+            Assert.Equal(data[1], 100);
+        }
+
 
         [Fact]
         public void pattern_ffi_option_nullable()
